==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QAbstractExtensionFactory.java <==
package io.qt.designer;


/**
 * <p>Interface for extension factories in Qt Designer</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html">QAbstractExtensionFactory</a></p>
 */
public interface QAbstractExtensionFactory extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QAbstractExtensionFactory}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QAbstractExtensionFactory
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QAbstractExtensionFactory.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
                return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
            }
            private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QAbstractExtensionFactory instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html#extension">QAbstractExtensionFactory::extension(QObject*,QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
        
        private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html#extension">QAbstractExtensionFactory::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QAbstractExtensionFactory.java <==
package io.qt.designer;


/**
 * <p>Interface for extension factories in Qt Designer</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html">QAbstractExtensionFactory</a></p>
 */
public interface QAbstractExtensionFactory extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QAbstractExtensionFactory}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QAbstractExtensionFactory
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QAbstractExtensionFactory.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
                return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
            }
            private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QAbstractExtensionFactory instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html#extension">QAbstractExtensionFactory::extension(QObject*,QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
        
        private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionfactory.html#extension">QAbstractExtensionFactory::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
    
}
